=======
Credits
=======

Development Lead
----------------

* Navin Sylvester <navinsylvester@gmail.com>

Contributors
------------

* Sreejith Kesevan (`@semk`_)

.. _`@navinsylvester`: https://github.com/navinsylvester
.. _`@semk`: https://github.com/semk
